ag_res_output: Write csv files of Agency/Program Standard Taxonomic...

Description Usage Arguments Value

View source: R/taxa_resolution.R

Description

Write csv files of Agency/Program Standard Taxonomic Resolution

Usage

1
ag_res_output(long, bioregion)

Arguments

long

= long data frame containing taxonomic counts.

col.ord

= a list of names used to sort the final output.

taxon

= The taxon of interest.

Value

Writes multiple csv files containing the percentage of taxa identified by each agency/program at the order, family and genus level.


zsmith27/CHESSIE documentation built on May 25, 2019, 7:24 p.m.