Description Usage Arguments Value
Clean Up Character Vectors
1 | clean_char(x)
|
x |
= A vector. |
Cleans up a character vector by verifying that it is class character, all characters are uppercase, and all leading/trailing white space has been removed.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.