plot.me: Import Output

Description Usage Arguments Value

View source: R/plot_me.R View source: R/simple_tables_figures.R

Description

Import Output

Plot Me

Usage

1
2
3
4
5
## S3 method for class 'me'
plot(scores.df, spatial, taxon_rank, todays_date)

## S3 method for class 'me'
plot(scores.df, spatial, taxon_rank, todays_date)

Arguments

scores.df

= a data frame containing final index scores.

bioregion

= specify the bioregion of interest.

my.data

=

index_res

= Spatial Resolution (i.e., "BASIN", "COAST", "INLAND", or "BIOREGION")

bioregion

= If index_res is set to "BIOREGION," then a list of bioregions to keep must be specified.

Value

Box-and-Whisker plots of final index scores aggregated by stream condition class.


zsmith27/CHESSIE documentation built on May 25, 2019, 7:24 p.m.