Description Usage Arguments Value
View source: R/plot_me.R View source: R/simple_tables_figures.R
Import Output
Plot Me
1 2 3 4 5 |
scores.df |
= a data frame containing final index scores. |
bioregion |
= specify the bioregion of interest. |
my.data |
= |
index_res |
= Spatial Resolution (i.e., "BASIN", "COAST", "INLAND", or "BIOREGION") |
bioregion |
= If index_res is set to "BIOREGION," then a list of bioregions to keep must be specified. |
Box-and-Whisker plots of final index scores aggregated by stream condition class.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.